==> react-atom-switch-1.15.0.tgz: package/lib/SwitchType/single.js <==
import { forwardRef } from 'react';
import cx from 'classnames';
import AtomLabel from '@s-ui/react-atom-label';
import { suitClass, switchClassNames } from './helpers';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export var SingleSwitchTypeRender = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _cx;

  var disabled = _ref.disabled,
      isFocus = _ref.isFocus,
      isClick = _ref.isClick,
      isToggle = _ref.isToggle,
      label = _ref.label,
      labelOptionalText = _ref.labelOptionalText,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      onClick = _ref.onClick,
      onKeyDown = _ref.onKeyDown,
      onToggle = _ref.onToggle,
      size = _ref.size,
      type = _ref.type,
      value = _ref.value;
  var isActive = value !== undefined ? value : isToggle;
  return /*#__PURE__*/_jsx("div", {
    className: switchClassNames(size, type, 'singleType', isActive, isFocus, isClick, disabled),
    onClick: function onClick() {
      return onToggle();
    },
    children: /*#__PURE__*/_jsxs("div", {
      className: suitClass({
        element: 'container'
      }),
      tabIndex: "0",
      onKeyDown: onKeyDown,
      onFocus: onFocus,
      onClick: onClick,
      onBlur: onBlur,
      ref: ref,
      children: [label && /*#__PURE__*/_jsx(AtomLabel, {
        name: name,
        text: label,
        optionalText: labelOptionalText
      }), /*#__PURE__*/_jsx("div", {
        className: suitClass({
          element: 'inputContainer'
        }),
        children: /*#__PURE__*/_jsx("div", {
          className: cx(suitClass({
            element: 'circle'
          }), (_cx = {}, _cx[suitClass({
            modifier: 'toggle'
          })] = isActive, _cx))
        })
      })]
    })
  });
});
SingleSwitchTypeRender.displayName = 'SingleSwitchTypeRender';

==> react-atom-switch-1.16.0.tgz: package/lib/SwitchType/single.js <==
import { forwardRef } from 'react';
import cx from 'classnames';
import AtomLabel from '@s-ui/react-atom-label';
import { suitClass, switchClassNames } from './helpers';
import PropTypes from 'prop-types';
import { LABELS } from '../config';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var RIGHT = LABELS.RIGHT,
    LEFT = LABELS.LEFT;
export var SingleSwitchTypeRender = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _cx;

  var disabled = _ref.disabled,
      isClick = _ref.isClick,
      isFocus = _ref.isFocus,
      isToggle = _ref.isToggle,
      label = _ref.label,
      labelLeft = _ref.labelLeft,
      labelOptionalText = _ref.labelOptionalText,
      labelRight = _ref.labelRight,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onClick = _ref.onClick,
      onFocus = _ref.onFocus,
      onKeyDown = _ref.onKeyDown,
      onToggle = _ref.onToggle,
      size = _ref.size,
      type = _ref.type,
      value = _ref.value;
  var isActive = value !== undefined ? value : isToggle;
  var defaultLabelLeft = labelLeft === LEFT;
  var defaultLabelRight = labelRight === RIGHT;
  var showLabelLeft = Boolean(label) || !defaultLabelLeft;
  var showLabelRight = !label && !defaultLabelRight && defaultLabelLeft;
  return /*#__PURE__*/_jsx("div", {
    className: switchClassNames(size, type, 'singleType', isActive, isFocus, isClick, disabled),
    onClick: function onClick() {
      return onToggle();
    },
    children: /*#__PURE__*/_jsxs("div", {
      className: suitClass({
        element: 'container'
      }),
      tabIndex: "0",
      onKeyDown: onKeyDown,
      onFocus: onFocus,
      onClick: onClick,
      onBlur: onBlur,
      ref: ref,
      children: [showLabelLeft && /*#__PURE__*/_jsx(AtomLabel, {
        name: name,
        text: defaultLabelLeft ? label : labelLeft,
        optionalText: labelOptionalText
      }), /*#__PURE__*/_jsx("div", {
        className: suitClass({
          element: 'inputContainer'
        }),
        children: /*#__PURE__*/_jsx("div", {
          className: cx(suitClass({
            element: 'circle'
          }), (_cx = {}, _cx[suitClass({
            modifier: 'toggle'
          })] = isActive, _cx))
        })
      }), showLabelRight && /*#__PURE__*/_jsx(AtomLabel, {
        name: name,
        text: labelRight,
        optionalText: labelOptionalText
      })]
    })
  });
});
SingleSwitchTypeRender.displayName = 'SingleSwitchTypeRender';
